summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmdimainfrm.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmdimainfrm.h')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdimainfrm.h31
1 files changed, 16 insertions, 15 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmdimainfrm.h b/lib/compatibility/kmdi/qextmdi/kmdimainfrm.h
index 68322f69..6f94451e 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdimainfrm.h
+++ b/lib/compatibility/kmdi/qextmdi/kmdimainfrm.h
@@ -6,8 +6,8 @@
// begin : 07/1999 by Szymon Stefanek as part of kvirc
// (an IRC application)
// changes : 09/1999 by Falk Brettschneider to create an
-// - 06/2000 stand-alone Qt extension set of
-// classes and a Qt-based library
+// - 06/2000 stand-alone TQt extension set of
+// classes and a TQt-based library
// : 02/2000 by Massimo Morin (mmorin@schedsys.com)
// 2000-2003 maintained by the KDevelop project
// patches : */2000 by Lars Beikirch (Lars.Beikirch@gmx.net)
@@ -69,7 +69,7 @@ class KMdiMainFrmPrivate;
*
* This special event is needed because the view has to inform the main frame that it`s being closed.
*/
-class KMDI_EXPORT KMdiViewCloseEvent : public QCustomEvent
+class KMDI_EXPORT KMdiViewCloseEvent : public TQCustomEvent
{
public:
KMdiViewCloseEvent( KMdiChildView* pWnd ) : TQCustomEvent( TQEvent::User, pWnd ) {}
@@ -78,7 +78,7 @@ public:
/**
* \short Base class for all your special main frames.
*
- * It contains the child frame area (QMainWindow's central widget) and a child view taskbar
+ * It contains the child frame area (TQMainWindow's central widget) and a child view taskbar
* for switching the MDI views. Most methods are virtual functions for later overriding.
*
* Basically, this class provides functionality for docking/undocking view windows and
@@ -98,7 +98,7 @@ public:
*
* \code
* MyMainWindow mainframe;
- * qApp->setMainWidget(&mainframe);
+ * tqApp->setMainWidget(&mainframe);
* mainframe->addWindow(view1); // put it under MDI control
* mainframe->addWindow(view2);
* \endcode
@@ -142,7 +142,7 @@ public:
* use fakeSDIApplication() to fake it and isFakingSDIApplication() to query whether or not an SDI
* interface is being faked.
*
- * You can dynamically change the shape of the attached MDI views using setFrameDecorOfAttachedViews().
+ * You can dynamically change the tqshape of the attached MDI views using setFrameDecorOfAttachedViews().
*
* Additionally, here's a hint how to restore the mainframe's settings from config file:
* \code
@@ -241,6 +241,7 @@ class KMDI_EXPORT KMdiMainFrm : public KParts::DockMainWindow
friend class KMdiChildView;
friend class KMdiTaskBar;
Q_OBJECT
+ TQ_OBJECT
friend class KMdiToolViewAccessor;
// attributes
@@ -296,7 +297,7 @@ private:
// methods
public:
- KMdiMainFrm( TQWidget* parentWidget, const char* name = "", KMdi::MdiMode mdiMode = KMdi::ChildframeMode, WFlags flags = WType_TopLevel | WDestructiveClose );
+ KMdiMainFrm( TQWidget* tqparentWidget, const char* name = "", KMdi::MdiMode mdiMode = KMdi::ChildframeMode, WFlags flags = WType_TopLevel | WDestructiveClose );
virtual ~KMdiMainFrm();
/**
@@ -354,7 +355,7 @@ public:
bool windowExists( KMdiChildView *pWnd, ExistsAs as );
/**
- * Catches certain Qt events and processes it here.
+ * Catches certain TQt events and processes it here.
* Currently, here this catches only the KMdiViewCloseEvent (a KMdi user event) which is sent
* from itself in childWindowCloseRequest() right after a KMdiChildView::closeEvent() .
* The reason for this event to itself is simple: It just wants to break the function call stack.
@@ -447,7 +448,7 @@ public:
*/
int childFrameModeHeight() { return m_oldMainFrmHeight; };
/**
- * Tells the MDI system a QMenu where it can insert buttons for
+ * Tells the MDI system a TQMenu where it can insert buttons for
* the system menu, undock, minimize, restore actions.
* If no such menu is given, KMdi simply overlays the buttons
* at the upper right-hand side of the main widget.
@@ -525,7 +526,7 @@ public slots:
/**
* Adds a KMdiChildView to the MDI system. The main frame takes control of it.
- * \param rectNormal Sets the geometry for this child view
+ * \param rectNormal Sets the tqgeometry for this child view
* \param flags the flags for the view such as:
* \li whether the view should be attached or detached.
* \li whether the view should be shown or hidden
@@ -548,7 +549,7 @@ public slots:
/**
* Using this method you have to use the setWidget method of the access object, and it is very recommendet, that you use
* the widgetContainer() method for the parent of your newly created widget
*/
KMdiToolViewAccessor *createToolWindow();
@@ -563,7 +564,7 @@ public slots:
* Removes a KMdiChildView from the MDI system and from the main frame`s control.
* Note: The view will be deleted!
*/
- virtual void closeWindow( KMdiChildView *pWnd, bool layoutTaskBar = true );
+ virtual void closeWindow( KMdiChildView *pWnd, bool tqlayoutTaskBar = true );
/**
* Switches the KMdiTaskBar on and off.
@@ -691,7 +692,7 @@ public slots:
virtual void tileAnodine() { m_pMdi->tileAnodine(); }
/**
- * Tile Vertically
+ * TileQt::Vertically
*/
virtual void tileVertically() { m_pMdi->tileVertically(); }
@@ -757,7 +758,7 @@ protected:
void blockClearingOfWindowMenu( bool bBlocked ) { m_bClearingOfWindowMenuBlocked = bBlocked; }
void findToolViewsDockedToMain( TQPtrList<KDockWidget>* list, KDockWidget::DockPosition dprtmw );
- void dockToolViewsIntoContainers( TQPtrList<KDockWidget>& widgetsToReparent, KDockWidget *container );
+ void dockToolViewsIntoContainers( TQPtrList<KDockWidget>& widgetsToRetqparent, KDockWidget *container );
TQStringList prepareIdealToTabs( KDockWidget* container );
void idealToolViewsToStandardTabs( TQStringList widgetNames, KDockWidget::DockPosition pos, int sizee );
@@ -869,4 +870,4 @@ signals:
#endif //_KMDIMAINFRM_H_
-// kate: space-indent off; tab-width 4; replace-tabs off; indent-mode csands;
+// kate: space-indent off; tab-width 4; tqreplace-tabs off; indent-mode csands;
@@ -548,7 +549,7 @@ public slots:
/**
* Using this method you have to use the setWidget method of the access object, and it is very recommendet, that you use
- * the widgetContainer() method for the parent of your newly created widget
+ * the widgetContainer() method for the tqparent of your newly created widget
*/
KMdiToolViewAccessor *createToolWindow();